aboutsummaryrefslogtreecommitdiffstats
path: root/core/namespace/Application.php
diff options
context:
space:
mode:
authorThomas Lange <code@nerdmind.de>2017-04-11 05:37:03 +0200
committerThomas Lange <code@nerdmind.de>2017-04-11 05:37:03 +0200
commitdd0433cf81fe5329b694a148191f09e427d4a56c (patch)
tree0bd9e44cbf17120027b33c4dd1ae6394c89c902a /core/namespace/Application.php
parent7a1b8f471ca133b6ca99cd4e440e6614a7c18537 (diff)
downloadblog-dd0433cf81fe5329b694a148191f09e427d4a56c.tar.gz
blog-dd0433cf81fe5329b694a148191f09e427d4a56c.tar.xz
blog-dd0433cf81fe5329b694a148191f09e427d4a56c.zip
Class "ExceptionHandler" has been removed and several files has been changed.
Diffstat (limited to 'core/namespace/Application.php')
-rw-r--r--core/namespace/Application.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/core/namespace/Application.php b/core/namespace/Application.php
index 17cd020..36dd2cd 100644
--- a/core/namespace/Application.php
+++ b/core/namespace/Application.php
@@ -137,11 +137,11 @@ class Application {
}
#===============================================================================
# Exit application with a custom HTTP status code
#===============================================================================
- public static function exit($code = 500) {
+ public static function exit($message = '', $code = 503) {
http_response_code($code);
- exit();
+ exit($message);
}
#===============================================================================
@@ -137,11 +137,11 @@ class Application {
}
#===============================================================================
- # Exit application with a custom HTTP status code
+ # Exit application with a custom message and status code
#===============================================================================